{+--------------------------------------------------------------------------+
 | Component:   TmwCustomFormComponent
 | Author:      Martin Waldenburg
 | Copyright    1997, all rights reserved.
 | Description: Base class for forms, which are components.
 |              The FormComponents will have a restricted visual representation
 |              as stored in the FormComponent's .DFM file, if dropped on a form.
 | Version:     1.2
 | Status:      Freeware
 | DISCLAIMER: This is provided as is, expressly without a warranty of any kind.
 |             You use it at your own risc.
 +--------------------------------------------------------------------------+}


unit mwCuFoCo;

interface

uses
  SysUtils,
  Windows,
  Messages,
  Classes,
  Graphics,
  Controls,
  StdCtrls,
  ExtCtrls,
  Forms,
  ComCtrls,
  Proxies,
  Menus;

type
  TmwCustomFormComponent = class(TForm)
  private
    Dummy: TForm;
    fLeftBorder: Integer;
    fTopBorder: Integer;
    fDisplayRepresentation:Boolean;
    function RunTime: Boolean;
    procedure CreateDummyForm;
    procedure GetRepresentation(value:Boolean);
  protected
    procedure SetBounds(Left, Top, Width, Height: Integer); override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property DisplayRepresentation:Boolean read fDisplayRepresentation
                                           write GetRepresentation;
  end;

var
  mwCustomFormComponent: TmwCustomFormComponent;

implementation

{$R *.DFM}

constructor TmwCustomFormComponent.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle - [csAcceptsControls, csSetCaption];
  Caption:='';
  fLeftBorder:= GetSystemMetrics(SM_CXBORDER) + GetSystemMetrics(SM_CXFIXEDFRAME);
  fTopBorder:= GetSystemMetrics(SM_CYCAPTION) + GetSystemMetrics(SM_CXBORDER) +
               GetSystemMetrics(SM_CXFIXEDFRAME); { use SM_CXFRAME for Windows 3.1 }

  if not RunTime then
    begin
      Height:= 31;
      Width:= 132;
      CreateDummyForm;
    end;
end;  { Create }

destructor TmwCustomFormComponent.Destroy;
begin
  Dummy.Free;
  Parent:= nil;
  inherited Destroy;
end;  { Destroy }

function TmwCustomFormComponent.RunTime: Boolean;
begin
  RunTime := not (csDesigning in ComponentState);
end;  { RunTime }

procedure TmwCustomFormComponent.SetBounds(Left, Top, Width, Height: Integer);
begin
  inherited SetBounds(Left, Top, Width, Height);
  if not RunTime then
    begin
      DisplayRepresentation:= True;
    end
  else
    begin
    end;
end;  { SetBounds }

procedure TmwCustomFormComponent.CreateDummyForm;
begin
  if not RunTime then
    begin
      if Dummy <> nil then Dummy.Free;
      Dummy:= TForm.Create(mwCustomFormComponent);
      ReadComponentRes(Self.ClassName, Dummy);
      Dummy.ControlStyle := Dummy.ControlStyle - [csAcceptsControls];
      Dummy.ShowHint:= True;
      Dummy.Hint:= 'This is a design time representation';
    end;
end;  { CreateDummyForm }

procedure TmwCustomFormComponent.GetRepresentation(value:Boolean);
begin
  if not RunTime then
    begin
      if Dummy = nil then  CreateDummyForm;
      Dummy.Left:= Left + (Owner as TForm).Left + fLeftBorder;
      Dummy.Top:= Top + (Owner as TForm).Top + fTopBorder;
      Dummy.Height:= Height;
      Dummy.Width:= Width;
      Dummy.Color:= Color;
      Dummy.Caption:= Name;
      Dummy.BorderStyle:= BorderStyle;
      Dummy.Show;
    end;
end;  { GetRepresentation }

end.

{ Martin Waldenburg
  Landaeckerstrasse 27
  71642 Ludwigsburg
  Germany  }

